@@ -1,3 +1,5 @@
+import json
+
 import allure
 import boto3
 import pandas as pd
@@ -67,7 +69,12 @@ class MyWhatify:
 
         :return: user ID or -1 if not exist
         """
-        return my_toolkit.UserManagement.get_user_id(email=email)
+        user_id = -1
+        if email:
+            user_id = my_toolkit.UserManagement.get_user_id(email=email)
+        else:
+            user_id = cls.user_token.get_user_id()
+        return user_id
 
     @classmethod
     def get_account_id(cls, email: str = None):
@@ -98,6 +105,7 @@ class MyWhatify:
                 my_toolkit.UserManagement.impersonate(user_id=user_id, admin_token=admin_token)
 
 
+
     #############################
     #######    API's      #######
     #############################
@@ -439,6 +447,20 @@ class MyWhatify:
             response = my_toolkit.Wisdom.update_wisdom(id=wisdom_id, data=wisdom_data, api_key=user_token)
         return response
 
+    @classmethod
+    def copy_wisdom(cls, base_wisdom_id: int, target_wisdom_id: int, user_token: str = None):
+        """
+        copy from base_wisdom_id to target_wisdom_id
+        :param base_wisdom_id:
+        :param target_wisdom_id:
+        :param user_token:
+        """
+        with allure.step(' '.join(['copying wisdom ID:', str(base_wisdom_id), 'to wisdom ID:', str(target_wisdom_id)])):
+            logging.info(' '.join(['Copying wisdom date from wisdom ID:', str(base_wisdom_id), 'to wisdom ID:', str(target_wisdom_id)]))
+            base = cls.get_wisdom(wisdom_id=base_wisdom_id).to_dict()
+            base.pop('id')
+            cls.update_wisdom(wisdom_id=target_wisdom_id, wisdom_data=base, user_token=user_token)
+
     @classmethod
     def delete_wisdom(cls, wisdom_id: int, user_token: str = None):
         """
@@ -455,11 +477,27 @@ class MyWhatify:
 
     @classmethod
     def get_wisdom_list(cls):
+        """
+        get wisdom list for current user
+        :return:
+        wisdom list
+        """
         with allure.step('getting wisdom list'):
             my_list = my_toolkit.Wisdom.get_wisdom_list_with_demo()
             len1 = len(my_list)
         return my_list
 
+    @classmethod
+    def get_wisdom(cls, wisdom_id: int):
+        """
+        get wisdom for current user by ID
+        :param wisdom_id:
+        :return:
+        wisdom
+        """
+        with allure.step(' '.join(['getting wisdom ID:', str(wisdom_id)])):
+            return my_toolkit.Wisdom.get_wisdom(id=wisdom_id)
+
     #############################
     ###       Connector       ###
     #############################
